import React from 'react'
import { Form, Input, Radio } from 'antd'
import { useObservableState } from '@/common/hooks/useObservableState'
import { useExperimentGraph } from '@/pages/rx-models/experiment-graph'

export interface Props {
  name: string
  experimentId: string
}

export const ExperimentForm: React.FC<Props> = ({ experimentId, name }) => {
  const [form] = Form.useForm()

  const expGraph = useExperimentGraph(experimentId)
  const [activeExperiment] = useObservableState(expGraph.experiment$)

  const onValuesChange = ({ experimentName }: { experimentName: string }) => {
    expGraph.experiment$.next({ ...activeExperiment, name: experimentName })
  }

  React.useEffect(() => {
    form.setFieldsValue({
      experimentName: activeExperiment ? activeExperiment.name : '',
    })
  }, [activeExperiment])

  return (
    <Form
      form={form}
      layout="vertical"
      initialValues={{
        experimentName: activeExperiment ? activeExperiment.name : '',
      }}
      onValuesChange={onValuesChange}
      requiredMark={false}
    >
      <Form.Item name="experimentName" label="策略名称">
        <Input placeholder="请输入策略名称" />
      </Form.Item>
    </Form>
  )
}
